'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLX import _types as _cs
# End users want this...
from OpenGL.raw.GLX._types import *
from OpenGL.raw.GLX import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLX_NV_copy_buffer'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLX,'GLX_NV_copy_buffer',error_checker=_errors._error_checker)

@_f
@_p.types(None,ctypes.POINTER(_cs.Display),_cs.GLXContext,_cs.GLXContext,_cs.GLenum,_cs.GLenum,_cs.GLintptr,_cs.GLintptr,_cs.GLsizeiptr)
def glXCopyBufferSubDataNV(dpy,readCtx,writeCtx,readTarget,writeTarget,readOffset,writeOffset,size):pass
@_f
@_p.types(None,ctypes.POINTER(_cs.Display),_cs.GLXContext,_cs.GLXContext,_cs.GLuint,_cs.GLuint,_cs.GLintptr,_cs.GLintptr,_cs.GLsizeiptr)
def glXNamedCopyBufferSubDataNV(dpy,readCtx,writeCtx,readBuffer,writeBuffer,readOffset,writeOffset,size):pass



'''OpenGL extension IMG.user_clip_plane

This module customises the behaviour of the 
OpenGL.raw.GLES1.IMG.user_clip_plane to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/IMG/user_clip_plane.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES1 import _types, _glgets
from OpenGL.raw.GLES1.IMG.user_clip_plane import *
from OpenGL.raw.GLES1.IMG.user_clip_plane import _EXTENSION_NAME

def glInitUserClipPlaneIMG():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glClipPlanefIMG=wrapper.wrapper(glClipPlanefIMG).setInputArraySize(
    'eqn', 4
)
glClipPlanexIMG=wrapper.wrapper(glClipPlanexIMG).setInputArraySize(
    'eqn', 4
)
### END AUTOGENERATED SECTION